@@ -108,17 +108,11 @@ def handle_robot_options(
         robot_arguments, app.config.config_files, verbose_callback=app.verbose
     )
     try:
-        profile = load_robot_config_from_path(*config_files).combine_profiles(
-            *(app.config.profiles or []), verbose_callback=app.verbose
+        profile = (
+            load_robot_config_from_path(*config_files)
+            .combine_profiles(*(app.config.profiles or []), verbose_callback=app.verbose, error_callback=app.error)
+            .evaluated_with_env(verbose_callback=app.verbose, error_callback=app.error)
         )
-
-        if profile.env:
-            for k, v in profile.env.items():
-                os.environ[k] = str(v)
-                app.verbose(lambda: f"Set environment variable {k} to {v}")
-
-        profile = profile.evaluated()
-
     except (TypeError, ValueError) as e:
         raise click.ClickException(str(e)) from e
 
